<?php

namespace Drupal\custom_field\Normalizer;

use Drupal\custom_field\Plugin\DataType\CustomFieldEntityReference;
use Drupal\serialization\Normalizer\FieldItemNormalizer;

/**
 * Converts the entity_reference custom field value to a JSON:API structure.
 */
class EntityReferenceNormalizer extends FieldItemNormalizer {

  /**
   * {@inheritdoc}
   */
  protected $supportedInterfaceOrClass = CustomFieldEntityReference::class;

  /**
   * {@inheritdoc}
   */
  public function normalize($object, $format = NULL, array $context = []): array|string|int|float|bool|\ArrayObject|null {
    assert($object instanceof CustomFieldEntityReference);
    /** @var \Drupal\Core\Entity\EntityInterface $entity */
    if ($entity = $object->getEntity()) {
      $this->addCacheableDependency($context, $entity);
      $attributes = $this->serializer->normalize($entity, $format, $context);

      return $attributes;
    }

    return NULL;
  }

  /**
   * {@inheritdoc}
   */
  public function getSupportedTypes(?string $format): array {
    return [
      CustomFieldEntityReference::class => TRUE,
    ];
  }

}
