<?php

namespace Drupal\custom_field\Plugin\CustomField\FieldFormatter;

use Drupal\Core\Form\FormStateInterface;

/**
 * Plugin implementation of the 'entity reference ID' formatter.
 *
 * @FieldFormatter(
 *   id = "entity_reference_entity_id",
 *   label = @Translation("Entity ID"),
 *   description = @Translation("Display the ID of the referenced entity."),
 *   field_types = {
 *     "entity_reference",
 *   }
 * )
 */
class EntityReferenceIdFormatter extends EntityReferenceFormatterBase {

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state, array $settings) {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary($settings = []) {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function formatValue(array $settings) {
    $target_type = $settings['configuration']['target_type'];
    $entity_id = $settings['value'];
    $entity = $this->entityTypeManager
      ->getStorage($target_type)
      ->load($entity_id);
    if (empty($entity)) {
      return NULL;
    }

    $access = $this->checkAccess($entity);

    if (!$access->isAllowed()) {
      return NULL;
    }

    $build = [
      '#plain_text' => $entity_id,
      '#cache' => ['tags' => $entity->getCacheTags()],
    ];

    return $this->renderer->render($build);
  }

}
